==> nocc-1.8.1.tbz: www/nocc/lang/ko.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ko.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Korean (한국어)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Mhha
 * @author Roh,Kyoung-Min <rohbin@dreamwiz.com>
 * @author Yknok29
 */

$lang_locale = 'ko_KR.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = '아이디를 입력해주십시요';
$err_passwd_empty = '비밀번호를 입력해주십시요';
$alt_delete = '지울글선택';
$alt_delete_one = '편지지우기';
$alt_new_msg = '편지쓰기';
$alt_reply = '답장';
$alt_reply_all = '전체답장';
$alt_forward = '전달';
$alt_next = '다음';
$alt_prev = '이전';
$title_next_page = '다음 페이지';
$title_prev_page = '이전 페이지';
$title_next_msg = '다음 글';
$title_prev_msg = '이전 글';
$html_on = '선택';
$html_theme_label = '테마';
$html_welcome = '%1$s에 오신 것을 환영합니다';
$html_login = '접속아이디';
$html_passwd = '비밀번호';
$html_submit = '로그인';
$html_help = '도움말';
$html_server = '서버';
$html_wrong = '아이디가 없거나 비밀번호가 일치하지 않습니다';
$html_retry = '다시입력';
$html_remember = '설정내용 기억하기';
$html_msgperpage_label = '페이지당 메세지의 숫자';
$html_preferences = '선택사항';
$html_full_name_label = '성명';
$html_email_address_label = '이메일 주소';
$html_ccself = '본인참조';
$html_hide_addresses = '숨은 주소들';
$html_outlook_quoting = '아웃룩 형식 인용';
$html_reply_to = '답장 대상';
$html_use_signature = '서명 사용하기';
$html_signature = '서명';
$html_reply_leadin_label = '답장 확인';
$html_prefs_updated = '선택사항이 저장되었습니다.';
$html_manage_folders_link = 'IMAP 폴더 관리';
$html_manage_filters_link = '이메일 필터 관리';
$html_use_graphical_smilies = '그림 아이콘 사용하기';
$html_sent_folder_label = '지정된 폴더에 보낸 메일을 저장하기';
$html_trash_folder_label = '삭제한 메일을 지정된 폴더로 이동시키기';
$html_colored_quotes = '잘못된 인용들';
$html_display_struct = '화면에 보이는 문자';
$html_send_html_mail = 'HTML 형식으로 메일 보내기';
$html_folders = '폴더들';
$html_folders_create_failed = '폴더가 만들어지지 않았습니다!';
$html_folders_sub_failed = '폴더로 보내지지 않았습니다!';
$html_folders_unsub_failed = '폴더에서 지워지지 않았습니다!';
$html_folders_rename_failed = '폴더 이름이 변경되지 않았습니다!';
$html_folders_updated = '폴더들이 수정되었습니다.';
$html_folder_subscribe = '이동시킬 곳';
$html_folder_rename = '이름변경';
$html_folder_create = '새로운 폴더 만들기';
$html_folder_remove = '제거할 곳';
$html_folder_delete = '삭제';
$html_folder_to = '에게';
$html_filter_remove = '삭제';
$html_filter_body = '메세지 내용';
$html_filter_subject = '메세지 제목';
$html_filter_to = '받으실 분 목록';
$html_filter_cc = '참조 목록';
$html_filter_from = '발신자';
$html_filter_change_tip = '필터를 수정하시려면 그 위에 다시 쓰시면 됩니다.';
$html_reapply_filters = '모든 필터를 다시 승인하기';
$html_filter_contains = '포함';
$html_filter_name = '필터 이름';
$html_filter_action = '필터 사용';
$html_filter_moveto = '이동시킬 곳';
$html_select_one = '--한개를 선택하세요--';
$html_and = '그리고';
$html_new_msg_in = '새로운 메세지들이 있는 곳';
$html_or = '또는';
$html_move = '이동';
$html_copy = '복사';
$html_messages_to = '선택한 메세지를 보낼 곳';
$html_gotopage = '이동할 페이지';
$html_gotofolder = '폴더로 이동하기';
$html_other_folders = '폴더 리스트';
$html_page = '페이지';
$html_of = '의 근거';
$html_view_header = '헤더 보기';
$html_remove_header = '헤더 숨기기';
$html_inbox = '받은편지함';
$html_new_msg = '쓰기';
$html_reply = '답장';
$html_reply_short = '답장';
$html_reply_all = '전체답장';
$html_forward = '전달';
$html_forward_short = '전달';
$html_forward_info = '메세지가 첨부파일과 함께 지정된 분에게 전달될 것입니다.';
$html_delete = '삭제';
$html_new = '새로온 편지';
$html_mark = '삭제';
$html_att_label = '첨부';
$html_atts_label = '첨부';
$html_att_unknown = '[모름]';
$html_attach = '첨부하기';
$html_attach_forget = '파일을 첨부하셔야 편지를 보낼수 있습니다.';
$html_attach_delete = '선택한 내용을 삭제하기';
$html_attach_none = '첨부하실 파일을 반드시 선택하셔야 합니다!';
$html_sort_by = '정렬 기준';
$html_sort = '정렬 시키기';
$html_from = '보낸이';
$html_subject = '제목';
$html_date = '날짜';
$html_sent = '보내기';
$html_wrote = '기록됨';
$html_size = '용량';
$html_totalsize = '총용량';
$html_kb = '키로바이트';
$html_mb = '메가바이트';
$html_gb = '기가바이트';
$html_bytes = '바이트';
$html_filename = '파일명';
$html_to = '받는사람';
$html_cc = '참조';
$html_bcc_label = '비밀참조';
$html_nosubject = '제목없음';
$html_send = '보내기';
$html_cancel = '취소';
$html_no_mail = '편지합이 비어있습니다';
$html_logout = '로그아웃';
$html_msg = ' 통의 편지가 있습니다';
$html_msgs = ' 통의 편지가 있습니다';
$html_configuration = '이 서버는 제대로 설정되지 않았습니다!';
$html_priority_label = '우선권';
$html_lowest = '최저의';
$html_low = '낮은';
$html_normal = '일반적인';
$html_high = '고급의';
$html_highest = '최상급의';
$html_receipt = '답신요청하기';
$html_select = '선택하기';
$html_select_all = '선택취소';
$html_loading_image = '사진 받는 중';
$html_send_confirmed = '편지 배달이 승인되었습니다.';
$html_no_sendaction = '정상적인 동작을 위해서 자바스크립트가 실행가능하도록 웹브라우저 설정을 변경하시기 바랍니다.';
$html_error_occurred = '오류가 발생하였습니다';
$html_prefs_file_error = '환경 저장에 실패하였습니다.';
$html_wrap = '발송 메세지들을 저장할 곳 :';
$html_wrap_none = '아님';
$html_usenet_separator = '서명전에 ("-- \n") 표시를 하여 주십시오';
$html_mark_as = '표시기준';
$html_read = '읽음';
$html_unread = '안읽음';
$html_encoding_label = '문자 변환';
$html_add = '더하기';
$html_contacts = '%1$s 연락처';
$html_modify = '수정';
$html_back = '뒤로';
$html_contact_add = '새로운 연락처 추가하기';
$html_contact_mod = '연락처 수정하기';
$html_contact_first = '이름(성씨제외)';
$html_contact_last = '성씨';
$html_contact_nick = '별명';
$html_contact_mail = '메일';
$html_contact_err1 = '한번에 보내실 수 있는 최대 수신자';
$original_msg = '-- 원본 내용 --';
$to_empty = '이메일(email) 주소를 입력하셔야 합니다.';
$html_images_warning = '귀하의 컴퓨터보안을 위해 외부의 사진파일을 보여주지 않았습니다.';

==> nocc-1.8.3.tbz: www/nocc/lang/ko.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ko.php 2164 2010-04-05 12:50:59Z gerundt $
 */

/** Korean (한국어)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Kwj2772
 * @author Mhha
 * @author Roh,Kyoung-Min <rohbin@dreamwiz.com>
 * @author Yknok29
 */

$lang_locale = 'ko_KR.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = '아이디를 입력해주십시요';
$err_passwd_empty = '비밀번호를 입력해주십시요';
$alt_delete = '지울글선택';
$alt_delete_one = '편지지우기';
$alt_new_msg = '편지쓰기';
$alt_reply = '답장';
$alt_reply_all = '전체답장';
$alt_forward = '전달';
$alt_next = '다음';
$alt_prev = '이전';
$title_next_page = '다음 페이지';
$title_prev_page = '이전 페이지';
$title_next_msg = '다음 글';
$title_prev_msg = '이전 글';
$html_theme_label = '테마';
$html_welcome = '%1$s에 오신 것을 환영합니다';
$html_login = '접속아이디';
$html_submit = '로그인';
$html_help = '도움말';
$html_wrong = '아이디가 없거나 비밀번호가 일치하지 않습니다';
$html_retry = '다시입력';
$html_remember = '설정내용 기억하기';
$html_msgperpage_label = '페이지당 메세지의 숫자';
$html_preferences = '선택사항';
$html_full_name_label = '성명';
$html_email_address_label = '이메일 주소:';
$html_ccself = '본인참조';
$html_hide_addresses = '숨은 주소들';
$html_outlook_quoting = '아웃룩 형식 인용';
$html_reply_to = '답장 대상';
$html_use_signature = '서명 사용하기';
$html_signature = '서명';
$html_reply_leadin_label = '답장 확인';
$html_prefs_updated = '선택사항이 저장되었습니다.';
$html_manage_folders_link = 'IMAP 폴더 관리';
$html_manage_filters_link = '이메일 필터 관리';
$html_use_graphical_smilies = '그림 아이콘 사용하기';
$html_sent_folder_label = '지정된 폴더에 보낸 메일을 저장하기';
$html_trash_folder_label = '삭제한 메일을 지정된 폴더로 이동시키기';
$html_colored_quotes = '잘못된 인용들';
$html_display_struct = '화면에 보이는 문자';
$html_send_html_mail = 'HTML 형식으로 메일 보내기';
$html_folders = '폴더들';
$html_folders_create_failed = '폴더가 만들어지지 않았습니다!';
$html_folders_sub_failed = '폴더로 보내지지 않았습니다!';
$html_folders_unsub_failed = '폴더에서 지워지지 않았습니다!';
$html_folders_rename_failed = '폴더 이름이 변경되지 않았습니다!';
$html_folders_updated = '폴더들이 수정되었습니다.';
$html_folder_subscribe = '이동시킬 곳';
$html_folder_rename = '이름변경';
$html_folder_create = '새로운 폴더 만들기';
$html_folder_remove = '제거할 곳';
$html_folder_delete = '삭제';
$html_folder_to = '에게';
$html_filter_remove = '삭제';
$html_filter_body = '메세지 내용';
$html_filter_subject = '메세지 제목';
$html_filter_to = '받으실 분 목록';
$html_filter_cc = '참조 목록';
$html_filter_from = '발신자';
$html_filter_change_tip = '필터를 수정하시려면 그 위에 다시 쓰시면 됩니다.';
$html_reapply_filters = '모든 필터를 다시 승인하기';
$html_filter_contains = '포함';
$html_filter_name = '필터 이름';
$html_filter_action = '필터 사용';
$html_filter_moveto = '이동시킬 곳';
$html_select_one = '--한개를 선택하세요--';
$html_and = '그리고';
$html_new_msg_in = '새로운 메세지들이 있는 곳';
$html_or = '또는';
$html_move = '이동';
$html_copy = '복사';
$html_messages_to = '선택한 메세지를 보낼 곳';
$html_gotopage = '이동할 페이지';
$html_gotofolder = '폴더로 이동하기';
$html_other_folders = '폴더 리스트';
$html_page = '페이지';
$html_of = '의 근거';
$html_view_header = '헤더 보기';
$html_remove_header = '헤더 숨기기';
$html_inbox = '받은편지함';
$html_new_msg = '쓰기';
$html_reply = '답장';
$html_reply_short = '답장';
$html_reply_all = '전체답장';
$html_forward = '전달';
$html_forward_short = '전달';
$html_forward_info = '메세지가 첨부파일과 함께 지정된 분에게 전달될 것입니다.';
$html_delete = '삭제';
$html_new = '새로온 편지';
$html_mark = '삭제';
$html_att_label = '첨부';
$html_unknown = '[모름]';
$html_attach = '첨부하기';
$html_attach_forget = '파일을 첨부하셔야 편지를 보낼수 있습니다.';
$html_attach_delete = '선택한 내용을 삭제하기';
$html_attach_none = '첨부하실 파일을 반드시 선택하셔야 합니다!';
$html_sort_by = '정렬 기준';
$html_sort = '정렬 시키기';
$html_from = '보낸이';
$html_subject = '제목';
$html_date = '날짜';
$html_sent_label = '보내기';
$html_wrote = '기록됨';
$html_size = '용량';
$html_totalsize = '총용량';
$html_kb = '키로바이트';
$html_mb = '메가바이트';
$html_gb = '기가바이트';
$html_bytes = '바이트';
$html_filename = '파일명';
$html_to = '받는사람';
$html_cc = '참조';
$html_bcc_label = '비밀참조';
$html_nosubject = '제목없음';
$html_send = '보내기';
$html_cancel = '취소';
$html_no_mail = '편지합이 비어있습니다';
$html_logout = '로그아웃';
$html_msg = ' 통의 편지가 있습니다';
$html_msgs = ' 통의 편지가 있습니다';
$html_configuration = '이 서버는 제대로 설정되지 않았습니다!';
$html_priority_label = '우선권';
$html_lowest = '최저의';
$html_low = '낮은';
$html_normal = '일반적인';
$html_high = '고급의';
$html_highest = '최상급의';
$html_receipt = '답신요청하기';
$html_select = '선택하기';
$html_select_all = '선택취소';
$html_loading_image = '사진 받는 중';
$html_send_confirmed = '편지 배달이 승인되었습니다.';
$html_no_sendaction = '정상적인 동작을 위해서 자바스크립트가 실행가능하도록 웹브라우저 설정을 변경하시기 바랍니다.';
$html_error_occurred = '오류가 발생하였습니다';
$html_prefs_file_error = '환경 저장에 실패하였습니다.';
$html_wrap = '발송 메세지들을 저장할 곳 :';
$html_wrap_none = '아님';
$html_usenet_separator = '서명전에 ("-- \n") 표시를 하여 주십시오';
$html_mark_as = '표시기준';
$html_read = '읽음';
$html_unread = '안읽음';
$html_encoding_label = '문자 변환';
$html_add = '더하기';
$html_contacts = '%1$s 연락처';
$html_modify = '수정';
$html_back = '뒤로';
$html_contact_add = '새로운 연락처 추가하기';
$html_contact_mod = '연락처 수정하기';
$html_contact_first = '이름(성씨제외)';
$html_contact_last = '성씨';
$html_contact_nick = '별명';
$html_contact_mail = '메일';
$html_contact_err1 = '한번에 보내실 수 있는 최대 수신자';
$original_msg = '-- 원본 내용 --';
$to_empty = '이메일(email) 주소를 입력하셔야 합니다.';
$html_images_warning = '귀하의 컴퓨터보안을 위해 외부의 사진파일을 보여주지 않았습니다.';
